==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/RowSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { RowSeparatorDescription } from "./RowSeparatorDescription";
/**
 * @hidden
 */
var RowSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RowSeparatorDescriptionMetadata, _super);
    function RowSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RowSeparatorDescriptionMetadata.b = function (a) {
        if (RowSeparatorDescriptionMetadata.a == null) {
            RowSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RowSeparatorDescriptionMetadata.c(RowSeparatorDescriptionMetadata.a);
        }
        if (a.g(RowSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.s(RowSeparatorDescriptionMetadata.a);
    };
    RowSeparatorDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    RowSeparatorDescriptionMetadata.d = function (a) {
        RowSeparatorDescriptionMetadata.b(a);
        a.u("RowSeparator", function () { return new RowSeparatorDescription(); });
        a.t("RowSeparator", RowSeparatorDescriptionMetadata.a);
    };
    RowSeparatorDescriptionMetadata.$t = markType(RowSeparatorDescriptionMetadata, 'RowSeparatorDescriptionMetadata');
    RowSeparatorDescriptionMetadata.a = null;
    return RowSeparatorDescriptionMetadata;
}(Base));
export { RowSeparatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/RowSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { RowSeparatorDescription } from "./RowSeparatorDescription";
/**
 * @hidden
 */
var RowSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RowSeparatorDescriptionMetadata, _super);
    function RowSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RowSeparatorDescriptionMetadata.b = function (a) {
        if (RowSeparatorDescriptionMetadata.a == null) {
            RowSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RowSeparatorDescriptionMetadata.c(RowSeparatorDescriptionMetadata.a);
        }
        if (a.j(RowSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.y(RowSeparatorDescriptionMetadata.a);
    };
    RowSeparatorDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    RowSeparatorDescriptionMetadata.d = function (a) {
        RowSeparatorDescriptionMetadata.b(a);
        a.aa("RowSeparator", function () { return new RowSeparatorDescription(); });
        a.z("RowSeparator", RowSeparatorDescriptionMetadata.a);
    };
    RowSeparatorDescriptionMetadata.$t = markType(RowSeparatorDescriptionMetadata, 'RowSeparatorDescriptionMetadata');
    RowSeparatorDescriptionMetadata.a = null;
    return RowSeparatorDescriptionMetadata;
}(Base));
export { RowSeparatorDescriptionMetadata };
